Implementation of the single-curvature BFSC (SC-BFSC) element, for linear and
nonlinear analyses.

Donnell-type and Sanders-type kinematics are available.

Github Actions status:

[![Actions Status](https://github.com/saullocastro/bfsccylinder/workflows/pytest/badge.svg)](https://github.com/saullocastro/bfsccylinder/actions)

Coverage status:

[![Codecov Status](https://codecov.io/gh/saullocastro/bfsccylinder/branch/master/graph/badge.svg?token=KD9D8G8D2P)](https://codecov.io/gh/saullocastro/bfsccylinder)


License
-------
Distrubuted under the 3-Clause BSD license
(https://raw.github.com/saullocastro/bfsccylinder/master/LICENSE).

Contacts:
- Saullo G. P. Castro, S.G.P.Castro@tudelft.nl

